from . import actions    #noqa
from . import composite  #noqa
from . import data       #noqa
from . import finish     #noqa
from . import meta       #noqa
from . import raw        #noqa
from . import start      #noqa



#!/usr/bin/env python
import argparse
from charms.benchmark import Benchmark


def main():
    parser = argparse.ArgumentParser(
        description='Set the composite result of a benchmark run.'
    )
    parser.add_argument(
        "key",
        metavar='key',
        help='The key of the data to store, i.e., .'
    )

    parser.add_argument(
        "value",
        metavar='value',
        help='The key of the data to store, i.e., .'
    )

    parser.add_argument(
        "units",
        metavar='units',
        nargs='?',
        help='''
        The type of units used to measure the composite, i.e., requests/sec.
        '''
    )
    parser.add_argument(
        "direction",
        metavar='direction',
        nargs='?',
        help='''
        The direction of how the composite should be interpreted. 'asc' if a
        lower number is better; 'desc' if a higher number is better.
        '''
    )

    args = parser.parse_args()

    Benchmark.set_data({'results.%s.value' % args.key: args.value})
    if args.units:
        Benchmark.set_data({'results.%s.units' % args.key: args.units})
    if args.direction:
        Benchmark.set_data({'results.%s.direction' % args.key: args.direction})

if __name__ == "__main__":
    main()



#!/usr/bin/env python
import argparse
from charms.benchmark import Benchmark


def main():
    parser = argparse.ArgumentParser(
        description='Set the raw results of a benchmark run.'
    )
    parser.add_argument(
        "value",
        metavar='value',
        help='The raw results of a benchmark run.',
        type=argparse.FileType('r')
    )

    args = parser.parse_args()

    Benchmark.set_data({'meta.raw': args.value.read()})

if __name__ == "__main__":
    main()



#!/usr/bin/env python
import argparse
from charms.benchmark import Benchmark


def main():
    parser = argparse.ArgumentParser(
        description='Set the composite result of a benchmark run.'
    )
    parser.add_argument(
        "composite",
        metavar='composite',
        help='The composite score of the benchmark run.'
    )
    parser.add_argument(
        "units",
        metavar='units',
        help='''
        The type of units used to measure the composite, i.e., requests/sec.
        '''
    )
    parser.add_argument(
        "direction",
        metavar='direction',
        help='''
        The direction of how the composite should be interpreted. 'asc' if a
        lower number is better; 'desc' if a higher number is better.
        '''
    )

    args = parser.parse_args()

    Benchmark().set_composite_score(args.composite, args.units, args.direction)

if __name__ == "__main__":
    main()



import os
import unittest
from testtools import TestCase

import mock
from charms.benchmark import Benchmark
from helpers import patch_open, FakeRelation


TO_PATCH = [
    'in_relation_hook',
    'relation_ids',
    'relation_set',
    'relation_get',
]

FAKE_RELATION = {
    'benchmark:0': {
        'benchmark/0': {
            'hostname': '127.0.0.1',
            'port': '1111',
            'graphite_port': '2222',
            'graphite_endpoint': 'http://localhost:3333',
            'api_port': '4444'
        }
    }
}


class TestBenchmarkCli(TestCase):

    def setUp(self):
        super(TestBenchmarkCli, self).setUp()
        for m in TO_PATCH:
            setattr(self, m, self._patch(m))
        self.fake_relation = FakeRelation(FAKE_RELATION)

        self.relation_get.side_effect = self.fake_relation.get
        self.relation_ids.side_effect = self.fake_relation.relation_ids

    def _patch(self, method):
        _m = mock.patch('charms.benchmark.' + method)
        m = _m.start()
        self.addCleanup(_m.stop)
        return m



from setuptools import setup, find_packages
import os.path

install_requires = [
    'PyYAML',
    'charmhelpers>=0.5.0'
]

tests_require = [
    'coverage',
    'nose',
    'pep8',
]

HERE = os.path.dirname(__file__)
with open(os.path.join(HERE, 'VERSION')) as f:
    VERSION = f.read().strip()

setup(
    name='charms.benchmark',
    version=VERSION,
    author='Adam Israel',
    author_email='adam@adamisrael.com',
    description='Library to aid in the creation of benchmark actions in Juju',
    install_requires=install_requires,
    url="https://github.com/juju-solutions/charms.benchmark",
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'benchmark-start = charms.benchmark.cli.start:main',
            'benchmark-finish = charms.benchmark.cli.finish:main',
            'benchmark-actions = charms.benchmark.cli.actions:main',
            'benchmark-composite = charms.benchmark.cli.composite:main',
            # An alias for benchmark-composite
            'benchmark-result = charms.benchmark.cli.composite:main',
            'benchmark-meta = charms.benchmark.cli.meta:main',
            'benchmark-data = charms.benchmark.cli.data:main',
            'benchmark-raw = charms.benchmark.cli.raw:main',
        ]
    }
)
